@@ -1,19 +1,23 @@
 
-import commands
+#import commands
+import subprocess
 
 class ipget:
 	def __init__(self):
 	#def ipgeter(self):	
 		i =0
 		old = []
-		ifcon =commands.getoutput("ip addr")
+		a = []
+		ifcon = subprocess.check_output(['ip', 'addr']).decode('utf-8')
+		#ifcon =commands.getoutput("ip addr")
 		outcom = ifcon.splitlines()
-		for j in outcom:
-			new = outcom[i].split(' ')
-			while new.count("") > 0:
-				new.remove("")
+		#print (outcom)
+		for j in (outcom):
+			a = outcom[i].split(" ")
+			while a.count("") > 0:
+				a.remove("")
 			#print new
-			old = old + new
+			old = old + a
 			i = i +1
 		self.list = old
 		#print self.list
